@@ -175,8 +175,18 @@ echo ""
 echo "Running update process..."
 
 if [ "$AUTO_MODE" = true ]; then
-    # In auto mode, modify the update script to skip confirmation
-    yes | ./update.sh
+    # In auto mode, provide 'y' to confirmation prompt
+    echo "y" | ./update.sh 2>&1 || {
+        # Handle pipe error gracefully - update may have succeeded
+        EXIT_CODE=$?
+        if [ $EXIT_CODE -eq 141 ]; then
+            # Exit code 141 = SIGPIPE, which is expected when 'echo y' pipe is closed
+            echo "Update process completed (pipe closed normally)"
+        else
+            echo "Update failed with exit code: $EXIT_CODE"
+            exit $EXIT_CODE
+        fi
+    }
 else
     ./update.sh
 fi
